/**
 * CTU Open 2018
 * Problem Solution: Numbers Generator
 *
 * @author Josef Cibulka
 */

#include <cassert>
#include <iomanip>
#include <iostream>
#include <vector>
#include <set>
#include <map>

using namespace std;

int get_bin_len(int64_t n)
{
  int ret = 0;
  while (n)
  {
    n >>= 1;
    ret++;
  }
  return ret;
}

// Finds longest suffix of n in list and returns its index.
int find_longest_suffix(int64_t n, const map<int64_t, int> &list)
{
  int len = get_bin_len(n);
  int64_t suff = n;
  for (int i = len-1; i >= 0; --i)
  {
    const auto &iter = list.find(suff);
    if (iter != list.cend())
    {
      return iter->second;
    }
    // Remove the second most significant bit and move the MSB one lower.
    if (i > 0)
      suff = ((suff - (1LL<<i)) | (1LL<<(i-1LL)));
  }
  assert(false);
}

// Gaussian elimination.
long double solve (vector<vector<long double>> eqs)
{
  int eq_cnt = eqs.size();
  vector<long double> last_row;
  last_row.resize(eq_cnt, 0); 
  last_row.push_back(1);
  eqs.push_back(last_row);
  for (int ii = 0; ii < 100; ++ii)
  {
    vector<vector<long double>> eqs_new = eqs;
    for (int i=0; i < eq_cnt+1; ++i)
      for (int j=0; j < eq_cnt+1; ++j)
      {
        eqs_new[i][j] = 0;
        for (int k=0; k < eq_cnt+1; ++k)
         eqs_new[i][j] += eqs[i][k] * eqs[k][j];
      }
    eqs = eqs_new;
  }

  vector<long double> sol;
  sol.resize(eq_cnt, 1); 
  
  vector<vector<long double>> eqs_orig = eqs;
  {
    vector<long double> sol_next;
    sol_next.resize(eq_cnt, 0); 
    for (int j = 0; j < eq_cnt; ++j)
    {
      for (int k = 0; k < eq_cnt; ++k)
        if(eqs_orig[j][k] != 0)
          sol_next[j] += eqs_orig[j][k] * sol[k];
      sol_next[j] += eqs_orig[j][eq_cnt]; 
    }
    sol = sol_next;
  }  
  return sol[0];
}

int main(void)
{
  int size, len;
  while (cin >> size >> len)
  {
    // Prefix to index mapping, the empty string has index 0.
    // Strings are prefixed with "1" to represent the length and then converted
    // to a binary number.
    map<int64_t, int> prefixes;
    for (int i = 0; i < size; ++i)
    {
      string s;
      cin >> s;
      for (char &l : s)
        l = (l == 'H' ? '0' : '1');
      for (int j = 0; j <= len; ++j)
      {
        string pref = "1" + s.substr(0,j);
        int64_t pref_id = std::stoll(pref, nullptr, 2);
        if(prefixes.find(pref_id) == prefixes.end())
        {
          prefixes.insert(make_pair(pref_id, 0));
        }
      }
    }
    // Index the map items.
    {
      int id = 0;
      for (auto &pair : prefixes)
      {
        pair.second = id;
        ++id;
      }
    }

    int var_cnt = prefixes.size();
    vector<vector<long double>> equations;
    equations.resize(var_cnt);
    for (auto &eq : equations)
    {
      eq.resize(var_cnt + 1, 0);
    }

    for (const auto &p : prefixes)
    {
      // cout << p.first << " : " << p.second << " children: ";
      int64_t pref = p.first;
      int index = p.second;
      if(get_bin_len(pref) == len+1)
      {
        // cout << endl;
        continue;
      }
      equations[index][var_cnt] = 1;
      for (int i=0; i<2; ++i)
      {
        int64_t pref_child = (pref<<1) + i;
        int child = find_longest_suffix(pref_child, prefixes);
        equations[index][child] = 0.5;
        // cout << child << " ";
      }
      // cout << endl;
    }

    cout << setprecision(5) << fixed << solve(equations) << endl;
  }
  return 0;
}
